pyconver
========

### Esse é um pacote que converte arquivos de diversas extensões.


## Instalação
    pip install pyconver

## Uso
```
import pyconver as cv
path = "path/to/file.extension"
converter = cv.pyconver(path)
converter.docx2pdf()
```